# Common parameters/functions for plotting land/sea mask, 
# topography of models using GrADS.
#
# List of Function(s):
#   [func. name]      [No. of arguments]    [output variables]
#   set_area_world            1              $lat_range, $lon_range
#
# List of programs:
#   ~/topo/cmip/combi_topo_lsmask_CMIP5.sh
#   ~/topo/cmip/lsmask_CMIP5_world.sh
#   ~/topo/cmip/topo_CMIP5_world.sh
#   ~/topo/JRA/lsmask_JRA_world.sh
#   ~/topo/JRA/topo_JRA_world.sh
#   ~/topo/NCEP_FNL/lsmask_NCEP_FNL.sh
#   ~/topo/NCEP_FNL/topo_NCEP_FNL_world.sh
#   ~/topo/NCEP/lsmask_NCEP1.sh
#   ~/topo/NCEP/topo_NCEP1_world.sh
#
#   last update: 2013-10-23
#   1st release: 2001-12-26
#
#   M. Hayasaki

### Parameters


### Functions
function set_area_world {
  local lcl_area=$1

case $lcl_area in
Japan)    # Japan, Korean Peninsula
  lat_range=" 25 48 "
  lon_range=" 123 147 "
  ;;
### Global
globe)
  lat_range="-90  90 "
  lon_range="  0 360 "
  ;;
### Continental-scale plot
E_Asia)
  lat_range=" 20  50 "
  lon_range="110 160 "
  ;;
all_Africa)
  lat_range="-20  40 "
  lon_range="-30  70 "
  ;;
all_N_America)
  lat_range=" 20  70 "
  lon_range="200 300 "
  ;;
all_Asia)
  lat_range=" 20  70 "
  lon_range=" 40 140 "
  ;;
all_Europe)
  lat_range=" 20  70 "
  lon_range="-20  80 "
  ;;
###############################
### Regional plot #############
###############################
Maritime_cont)
  lat_range=" -15 15 "
  lon_range="  95 145 "
  ;;
NW_America)
  lat_range=" 30 50 "
  lon_range=" -127 -97 "
  ;;
NE_America)   # *** NE America
  lat_range="   30  50"
  lon_range=" -102 -72"
  ;;
N_Europe)   # *** Northern Europe
  lat_range="  52 72"
  lon_range="  3  33"
  ;;
W_Europe)   # *** Western Europe
  lat_range="  35  55"
  lon_range=" -10  20"
  ;;
Ural)    # *** Ural
  lat_range=" 50 70"
  lon_range=" 40 70"
  ;;
Siberia)   # *** Siberia
  lat_range=" 50  70"
  lon_range=" 90 120"
  ;;
Mongolia)   # *** Mongolia
  lat_range="  35  55 "
  lon_range="  90 125 "
  ;;
Tibet)     # *** Tiebtan Plateau
  lat_range=" 25  45 "
  lon_range=" 70 105 "
  ;;
Indochina)    # *** Southeast Asia (Indochina)
  lat_range="  3  23 "
  lon_range=" 80 115 "
  ;;
Andes)    # South America (Guiana Highlands, Andes)
  lat_range="  -5  15 "
  lon_range=" -80 -50 "
  ;;
esac

}


### Changes
# 2013-10-11: Add new script (for CMIP5)
# 2009-12-14: Add new script (for JRA25)
# 2006-07-21: Add new script (for NCEP FNL)
# 2004-09-23: Add new script (for ERA40)
# 2001-12-26: Make function (for NCEP-NCAR Reanal.)
